@@ -2,6 +2,7 @@ package Dancer::Serializer::JSON;
 
 use strict;
 use warnings;
+use Carp;
 use Dancer::ModuleLoader;
 use Dancer::Config 'setting';
 use base 'Dancer::Serializer::Abstract';
@@ -25,7 +26,7 @@ sub loaded { Dancer::ModuleLoader->load('JSON') }
 
 sub init {
     my ($self) = @_;
-    die 'JSON is needed and is not installed'
+    croak 'JSON is needed and is not installed'
       unless $self->loaded;
 }
 
